==> kubernetes-model-0.1.4-sources.jar: annotations/io/fabric8/kubernetes/api/model/ServiceAccountFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ServiceAccountFluent<T extends ServiceAccountFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     ServiceAccount.ApiVersion apiVersion;     List<LocalObjectReference> imagePullSecrets = new ArrayList();     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     List<VisitableBuilder<ObjectReference, ?>> secrets = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public ServiceAccount.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( ServiceAccount.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public T addToImagePullSecrets( LocalObjectReference item){
    if (item != null) {this.imagePullSecrets.add(item);} return (T)this;
    }
    public List<LocalObjectReference> getImagePullSecrets(){
    return this.imagePullSecrets;
    }
    public T withImagePullSecrets( List<LocalObjectReference> imagePullSecrets){
    this.imagePullSecrets.clear();if (imagePullSecrets != null) {for (LocalObjectReference item : imagePullSecrets){this.addToImagePullSecrets(item);}} return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToSecrets( ObjectReference item){
    if (item != null) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.add(builder);this.secrets.add(builder);} return (T)this;
    }
    public List<ObjectReference> getSecrets(){
    return build(secrets);
    }
    public T withSecrets( List<ObjectReference> secrets){
    this.secrets.clear();if (secrets != null) {for (ObjectReference item : secrets){this.addToSecrets(item);}} return (T) this;
    }
    public SecretsNested<T> addNewSecret(){
    return new SecretsNested<T>();
    }
    public SecretsNested<T> addNewSecretLike( ObjectReference item){
    return new SecretsNested<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) ServiceAccountFluent.this.withMetadata(builder.build());
        }
    
}
    public class SecretsNested<N> extends ObjectReferenceFluent<SecretsNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             SecretsNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             SecretsNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endSecret(){
            return and();
        }
            public N and(){
            return (N) ServiceAccountFluent.this.addToSecrets(builder.build());
        }
    
}


}

==> kubernetes-model-1.0.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/ServiceAccountFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.util.HashMap;
import java.util.Map;
import java.util.List;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class ServiceAccountFluent<T extends ServiceAccountFluent<T>> extends BaseFluent<T> implements Fluent<T>{

     ServiceAccount.ApiVersion apiVersion;     List<LocalObjectReference> imagePullSecrets = new ArrayList();     String kind;     VisitableBuilder<ObjectMeta, ?> metadata;     List<VisitableBuilder<ObjectReference, ?>> secrets = new ArrayList();     Map<String, Object> additionalProperties = new HashMap();

    public ServiceAccount.ApiVersion getApiVersion(){
    return this.apiVersion;
    }
    public T withApiVersion( ServiceAccount.ApiVersion apiVersion){
    this.apiVersion=apiVersion; return (T) this;
    }
    public T addToImagePullSecrets( LocalObjectReference ...items){
    for (LocalObjectReference item : items) {this.imagePullSecrets.add(item);} return (T)this;
    }
    public List<LocalObjectReference> getImagePullSecrets(){
    return this.imagePullSecrets;
    }
    public T withImagePullSecrets( List<LocalObjectReference> imagePullSecrets){
    this.imagePullSecrets.clear();if (imagePullSecrets != null) {for (LocalObjectReference item : imagePullSecrets){this.addToImagePullSecrets(item);}} return (T) this;
    }
    public T withImagePullSecrets( LocalObjectReference ...imagePullSecrets){
    this.imagePullSecrets.clear(); if (imagePullSecrets != null) {for (LocalObjectReference item :imagePullSecrets){ this.addToImagePullSecrets(item);}} return (T) this;
    }
    public String getKind(){
    return this.kind;
    }
    public T withKind( String kind){
    this.kind=kind; return (T) this;
    }
    public ObjectMeta getMetadata(){
    return this.metadata!=null?this.metadata.build():null;
    }
    public T withMetadata( ObjectMeta metadata){
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (T) this;
    }
    public MetadataNested<T> withNewMetadata(){
    return new MetadataNested<T>();
    }
    public MetadataNested<T> withNewMetadataLike( ObjectMeta item){
    return new MetadataNested<T>(item);
    }
    public MetadataNested<T> editMetadata(){
    return withNewMetadataLike(getMetadata());
    }
    public T addToSecrets( ObjectReference ...items){
    for (ObjectReference item : items) {ObjectReferenceBuilder builder = new ObjectReferenceBuilder(item);_visitables.add(builder);this.secrets.add(builder);} return (T)this;
    }
    public List<ObjectReference> getSecrets(){
    return build(secrets);
    }
    public T withSecrets( List<ObjectReference> secrets){
    this.secrets.clear();if (secrets != null) {for (ObjectReference item : secrets){this.addToSecrets(item);}} return (T) this;
    }
    public T withSecrets( ObjectReference ...secrets){
    this.secrets.clear(); if (secrets != null) {for (ObjectReference item :secrets){ this.addToSecrets(item);}} return (T) this;
    }
    public SecretsNested<T> addNewSecret(){
    return new SecretsNested<T>();
    }
    public SecretsNested<T> addNewSecretLike( ObjectReference item){
    return new SecretsNested<T>(item);
    }
    public T addToAdditionalProperties( String key,  Object value){
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (T)this;
    }
    public Map<String, Object> getAdditionalProperties(){
    return this.additionalProperties;
    }
    public T withAdditionalProperties( Map<String, Object> additionalProperties){
    this.additionalProperties.clear();if (additionalProperties != null) {this.additionalProperties.putAll(additionalProperties);} return (T) this;
    }

    public class MetadataNested<N> extends ObjectMetaFluent<MetadataNested<N>> implements Nested<N>{

        private final ObjectMetaBuilder builder;
    
             MetadataNested (){
        this.builder = new ObjectMetaBuilder(this);
        }
             MetadataNested ( ObjectMeta item){
        this.builder = new ObjectMetaBuilder(this, item);
        }
    
            public N endMetadata(){
            return and();
        }
            public N and(){
            return (N) ServiceAccountFluent.this.withMetadata(builder.build());
        }
    
}
    public class SecretsNested<N> extends ObjectReferenceFluent<SecretsNested<N>> implements Nested<N>{

        private final ObjectReferenceBuilder builder;
    
             SecretsNested (){
        this.builder = new ObjectReferenceBuilder(this);
        }
             SecretsNested ( ObjectReference item){
        this.builder = new ObjectReferenceBuilder(this, item);
        }
    
            public N endSecret(){
            return and();
        }
            public N and(){
            return (N) ServiceAccountFluent.this.addToSecrets(builder.build());
        }
    
}


}
